

#include <sys/soundcard.h>


enum DSP_MODE { DSP_PLAY, DSP_RECORD };


/* Both count and size are always measured in bytes. On success all functions,
except of buffer_size(), return 1. buffer_size() of course returns the size of
the audio buffer. On error, all functions print an error messages on cerr and
return 0. */

/* open() ensures that all parameters are set as requested. If this is not
possible, open() fails. A buffer_size of 0 (default) means that the
sounddrivers default buffer size and fragment number are used. buffer_size
must be a power of 2. */

/* It's recommended to read and write exactly buffer_size() bytes a time, but
any other value works too. */


class DSP {

public:
  
  DSP();
  ~DSP();
  
  int open( DSP_MODE mode, int format, int stereo, int speed, int buffer_size = 0 );
  int close();
  int sync();
  
  void status();
  
  int read( void *buffer, int count );
  int write( void *buffer, int count );
  
  void swapbuffer( void *buffer, int count );
  
  int buffer_size() const;
  
private:
  
  int audio_format;
  int audio_stereo;
  int audio_speed;
  int audio_buffer_size;
  
  int audio_fd;
  /* int audio_caps; */
  
};



inline
DSP::DSP()
{
  audio_fd = -1;
}


inline
DSP::~DSP()
{
  if( audio_fd != -1 )
    close();
}


inline int
DSP::buffer_size() const
{
  return audio_buffer_size;
}

